Executors
=========

Execution contexts for handlers.

Base Executor
-------------

.. automodule:: genro_asgi.executors.base
   :members:
   :undoc-members:
   :show-inheritance:

Local Executor
--------------

.. automodule:: genro_asgi.executors.local
   :members:
   :undoc-members:
   :show-inheritance:

Executor Registry
-----------------

.. automodule:: genro_asgi.executors.registry
   :members:
   :undoc-members:
   :show-inheritance:
